<?php
// wcf imports
require_once(WCF_DIR.'lib/acp/form/ACPForm.class.php');
require_once(WCF_DIR.'lib/system/style/StyleManager.class.php');

// wbb imports
require_once(WBB_DIR.'lib/data/thread/LatestPostsAndThreadsListEditor.class.php');

/**
 * Shows the latest posts and threads list add form.
 * 
 * @author 	Nerd Almighty
 * @copyright	2009 Bergwerk <http://bergwerk.forenberg.de>
 * @license	Creative Commons - Attribution-Noncommercial-Share Alike 3.0 Unported <http://creativecommons.org/licenses/by-nc-sa/3.0/>
 * @package	com.bergwerk.wbb.page.user.latestPostsAndThreads
 * @subpackage	acp.form
 * @category 	Burning Board
 */
class LatestPostsAndThreadsListAddForm extends ACPForm {
	// system
	public $templateName = 'latestPostsAndThreadsListAdd';
	public $activeMenuItem = 'wbb.acp.menu.link.content.board.latestPostsAndThreadsList.add';
	public $neededPermissions = 'admin.board.canEditLatestPostsAndThreadsList';
	public $activeTabMenuItem = 'contents';
	
	/**
	 * list editor object
	 * 
	 * @var	LatestPostsAndThreadsListEditor
	 */
	public $list;
	
	/**
	 * list of available styles
	 * 
	 * @var	array
	 */
	public $styleOptions = array();
	
	/**
	 * list of available boards
	 * 
	 * @var	array
	 */
	public $boardOptions = array();
	
	// parameters
	public $title = '';
	public $isEnabled = 1;
	public $isDefault = 0;
	public $includedBoards = array();
	public $includeAllBoards = 0;
	public $excludedBoards = array();
	public $parentBoards = array();
	public $length = 0;
	public $design = 0;
	public $showStatusDisplayIcons = -1;
	public $showColumnRating = -1;
	public $showColumnReplies = -1;
	public $showColumnViews = -1;
	public $showLastPostTimeIcon = -1;
	public $daysPrune = 0;
	public $styleID = 0;
	public $enforceStyle = 0;
	
	/**
	 * @see Page::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
	}
	
	/**
	 * @see Form::readFormParameters()
	 */
	public function readFormParameters() {
		parent::readFormParameters();
		
		$this->isDefault = $this->isEnabled = $this->enforceStyle = 0;
		
		if (isset($_POST['activeTabMenuItem'])) $this->activeTabMenuItem = $_POST['activeTabMenuItem'];
		if (isset($_POST['title'])) $this->title = StringUtil::trim($_POST['title']);		
		if (isset($_POST['isDefault'])) $this->isDefault = intval((boolean) $_POST['isDefault']);
		if (isset($_POST['isEnabled'])) $this->isEnabled = intval((boolean) $_POST['isEnabled']);
		if (isset($_POST['includedBoards']) && is_array($_POST['includedBoards'])) $this->includedBoards = ArrayUtil::toIntegerArray($_POST['includedBoards']);
		if (isset($_POST['includeAllBoards'])) $this->includeAllBoards = intval((boolean) $_POST['includeAllBoards']);
		if (isset($_POST['excludedBoards']) && is_array($_POST['excludedBoards'])) $this->excludedBoards = ArrayUtil::toIntegerArray($_POST['excludedBoards']);
		if (isset($_POST['parentBoards']) && is_array($_POST['parentBoards'])) $this->parentBoards = ArrayUtil::toIntegerArray($_POST['parentBoards']);
		if (isset($_POST['length'])) $this->length = intval($_POST['length']);
		if (isset($_POST['design'])) $this->design = intval($_POST['design']);
		if (isset($_POST['showStatusDisplayIcons'])) $this->showStatusDisplayIcons = intval($_POST['showStatusDisplayIcons']);
		if (isset($_POST['showColumnRating'])) $this->showColumnRating = intval($_POST['showColumnRating']);
		if (isset($_POST['showColumnReplies'])) $this->showColumnReplies = intval($_POST['showColumnReplies']);
		if (isset($_POST['showColumnViews'])) $this->showColumnViews = intval($_POST['showColumnViews']);
		if (isset($_POST['showLastPostTimeIcon'])) $this->showLastPostTimeIcon = intval($_POST['showLastPostTimeIcon']);
		if (isset($_POST['daysPrune'])) $this->daysPrune = intval($_POST['daysPrune']);
		if (isset($_POST['styleID'])) $this->styleID = intval($_POST['styleID']);
		if (isset($_POST['enforceStyle'])) $this->enforceStyle = intval((boolean) $_POST['enforceStyle']);
	}
	
	/**
	 * @see Form::validate()
	 */
	public function validate() {
		$this->readBoardOptions();
		$this->readStyleOptions();
		
		parent::validate();
		
		// a default list can never be disabled
		if ($this->isDefault) $this->isEnabled = 1;
		
		// strip invalid board ids
		$boardIDs = array_keys($this->boardOptions);
		$this->includedBoards = array_intersect($this->includedBoards, $boardIDs);
		$this->excludedBoards = array_intersect($this->excludedBoards, $boardIDs);
		$this->parentBoards = array_intersect($this->parentBoards, $boardIDs);
		if ($this->includeAllBoards) $this->includedBoards = array();
		if (!$this->includeAllBoards) $this->excludedBoards = array();
		
		// reset invalid style id
		if ($this->styleID && !array_key_exists($this->styleID, $this->styleOptions)) $this->styleID = 0;
		
		// reset invalid length and daysPrune options
		$validLength = array(0, 3, 5, 10, 15);
		$validDaysPrune = array(0, 1, 3, 7, 14, 30, 60, 100, 365, 1000);
		if (!in_array($this->length, $validLength)) $this->length = 0;
		if (!in_array($this->daysPrune, $validDaysPrune)) $this->daysPrune = 0;
		
		// reset invalid select values
		if ($this->showStatusDisplayIcons > 1 || $this->showStatusDisplayIcons < -1) $this->showStatusDisplayIcons = -1;
		if ($this->showColumnRating > 1 || $this->showColumnRating < -1) $this->showColumnRating = -1;
		if ($this->showColumnReplies > 1 || $this->showColumnReplies < -1) $this->showColumnReplies = -1;
		if ($this->showColumnViews > 1 || $this->showColumnViews < -1) $this->showColumnViews = -1;
		if ($this->showLastPostTimeIcon > 1 || $this->showLastPostTimeIcon < -1) $this->showLastPostTimeIcon = -1;
		
		// the title is the only required value
		if ($this->title == '') {
			throw new UserInputException('title');
		}
	}
	
	/**
	 * @see Form::save()
	 */
	public function save() {
		parent::save();
		
		// implode selected boards
		$includedBoards = (count($this->includedBoards) ? implode(',', $this->includedBoards) : '');
		$excludedBoards = (count($this->excludedBoards) ? implode(',', $this->excludedBoards) : '');
		$parentBoards = (count($this->parentBoards) ? implode(',', $this->parentBoards) : '');
		
		// save list
		$fields = array(
			'isEnabled' => $this->isEnabled,
			'isDefault' => $this->isDefault,
			'includedBoards' => $includedBoards,
			'includeAllBoards' => $this->includeAllBoards,
			'excludedBoards' => $excludedBoards,
			'parentBoards' => $parentBoards,
			'length' => $this->length,
			'design' => $this->design,
			'showStatusDisplayIcons' => $this->showStatusDisplayIcons,
			'showColumnRating' => $this->showColumnRating,
			'showColumnReplies' => $this->showColumnReplies,
			'showColumnViews' => $this->showColumnViews,
			'showLastPostTimeIcon' => $this->showLastPostTimeIcon,
			'daysPrune' => $this->daysPrune,
			'styleID' => $this->styleID,
			'enforceStyle' => $this->enforceStyle
		);
		
		$this->list = LatestPostsAndThreadsListEditor::create($this->title, $fields);

		$this->saved();
		
		// reset values
		$this->title = '';
		$this->isEnabled = 1;
		$this->includedBoards = $this->excludedBoards = $this->parentBoards = array();
		$this->isDefault = $this->includeAllBoards = $this->length = $this->design = 0;
		$this->showStatusDisplayIcons = $this->showColumnRating = $this->showColumnReplies = $this->showColumnViews = $this->showLastPostTimeIcon = -1;
		$this->daysPrune = $this->styleID = $this->enforceStyle = 0;
		
		// show success message
		WCF::getTPL()->assign(array(
			'list' => $this->list,
			'success' => true
		));
	}
	
	/**
	 * @see Page::readData()
	 */
	public function readData() {
		parent::readData();
		
		$this->readBoardOptions();
		$this->readStyleOptions();
	}
	
	/**
	 * Gets a list of existing boards.
	 */
	protected function readBoardOptions() {
		$this->boardOptions = Board::getBoardSelect(array(), true, true);
	}
	
	/**
	 * Gets a list of available styles.
	 */
	protected function readStyleOptions() {
		$this->styleOptions = StyleManager::getAvailableStyles();
	}
	
	/**
	 * @see Page::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			'action' => 'add',
			'activeTabMenuItem' => $this->activeTabMenuItem,
			'styleOptions' => $this->styleOptions,
			'boardOptions' => $this->boardOptions,
			'title' => $this->title,
			'isDefault' => $this->isDefault,
			'isEnabled' => $this->isEnabled,
			'includedBoards' => $this->includedBoards,
			'includeAllBoards' => $this->includeAllBoards,
			'excludedBoards' => $this->excludedBoards,
			'parentBoards' => $this->parentBoards,
			'length' => $this->length,
			'design' => $this->design,
			'showStatusDisplayIcons' => $this->showStatusDisplayIcons,
			'showColumnRating' => $this->showColumnRating,
			'showColumnReplies' => $this->showColumnReplies,
			'showColumnViews' => $this->showColumnViews,
			'showLastPostTimeIcon' => $this->showLastPostTimeIcon,
			'daysPrune' => $this->daysPrune,
			'styleID' => $this->styleID,
			'enforceStyle' => $this->enforceStyle
		));
	}
	
	/**
	 * @see Page::show()
	 */
	public function show() {
		parent::show();
		
		// check permission
		WCF::getUser()->checkPermission($this->neededPermissions);
	}
}
?>