<?php
// wcf imports
require_once(WCF_DIR.'lib/page/AbstractFeedPage.class.php');

// wbb imports
require_once(WBB_DIR.'lib/page/PostsFeedPage.class.php');
require_once(WBB_DIR.'lib/data/thread/LatestPostsAndThreadsList.class.php');

/**
 * Prints a list of latest posts and threads as a rss or an atom feed.
 * 
 * @author 	Nerd Almighty
 * @copyright	2009-2010 Bergwerk <http://bergwerk.forenberg.de>
 * @license	Creative Commons - Attribution-Noncommercial-Share Alike 3.0 Unported <http://creativecommons.org/licenses/by-nc-sa/3.0/>
 * @package	com.bergwerk.wbb.page.user.latestPostsAndThreads
 * @subpackage	page
 * @category 	Burning Board
 */
class LatestPostsAndThreadsFeedPage extends PostsFeedPage {
	// parameters
	public $listID = 0;
	
	/**
	 * holds the requested latest posts and threads list
	 * 
	 * @var	LatestPostsAndThreadsList
	 */
	public $list = null;
	
	/**
	 * @see Page::readParameters()
	 */
	public function readParameters() {
		AbstractFeedPage::readParameters();
		
		// get list id
		if (isset($_REQUEST['listID'])) $this->listID = intval($_REQUEST['listID']);
		// if no list id is set, use default list
		$this->list = ($this->listID ? new LatestPostsAndThreadsList($this->listID) : LatestPostsAndThreadsList::getDefaultList());
		// enter list
		$this->list->enter();
		$this->listID = ($this->listID ? $this->list->listID : 0);
	}
	
	/**
	 * Gets the posts for the feed.
	 */
	protected function readPosts() {
		// accessible boards
		$accessibleBoardIDArray = $this->list->getIncludedBoards();
		
		// limit the limit - because we really don't want a feed with a million posts...
		if ($this->limit > 50) $this->limit = 50;
		
		// use list setting if "hours" parameter is not set
		if ($this->hours <= 0) $this->hours = $this->list->getOption('daysPrune') * 24;
		
		// get thread ids by their lastPostTime first, to avoid an odd bug where new posts in old threads didnt show up
		$threadIDs = '0';
		$sql = "SELECT		thread.threadID as threadID
			FROM		wbb".WBB_N."_thread thread
			WHERE		thread.boardID IN (".implode(',', $accessibleBoardIDArray).")
					AND thread.lastPostTime > ".($this->hours != 24000 ? (TIME_NOW - $this->hours * 3600) : 0)."
			ORDER BY	thread.lastPostTime DESC";
		$result = WCF::getDB()->sendQuery($sql, $this->limit);
		while ($row = WCF::getDB()->fetchArray($result)) {
			$threadIDs .= ','.$row['threadID'];
		}
		
		// now use the thread ids to get the post ids
		$postIDs = '0';
		$sql = "SELECT		max(postID) as postID
			FROM		wbb".WBB_N."_post
			WHERE		threadID IN (".$threadIDs.")
					AND isDeleted = 0
					AND isDisabled = 0
			GROUP BY	threadID
			ORDER BY	time DESC";
		$result = WCF::getDB()->sendQuery($sql);
		while ($row = WCF::getDB()->fetchArray($result)) {
			$postIDs = $postIDs.','.$row['postID'];
		}
		
		// get posts
		if (!empty($postIDs)) {
			$sql = "SELECT		post.*, thread.topic, thread.firstPostID
				FROM		wbb".WBB_N."_post post
				LEFT JOIN	wbb".WBB_N."_thread thread
				ON 		(post.threadID = thread.threadID)
				WHERE		post.postID IN (".$postIDs.")
				ORDER BY	post.time DESC";
			$result = WCF::getDB()->sendQuery($sql, $this->limit);
			while ($row = WCF::getDB()->fetchArray($result)) {
				// manipulate post subject
				if ($row['postID'] != $row['firstPostID']) $row['subject'] = 'Re: '.$row['topic'];
				$this->posts[] = new FeedPost(null, $row);
			}
		}
	}
}
?>