<?php
// wcf imports
require_once(WCF_DIR.'lib/page/MultipleLinkPage.class.php');

// wbb imports
require_once(WBB_DIR.'lib/data/thread/LatestPostsAndThreadsList.class.php');

/**
 * Shows the latest posts and threads page
 * 
 * @author 	Nerd Almighty
 * @copyright	2009-2010 Bergwerk <http://bergwerk.forenberg.de>
 * @license	Creative Commons - Attribution-Noncommercial-Share Alike 3.0 Unported <http://creativecommons.org/licenses/by-nc-sa/3.0/>
 * @package	com.bergwerk.wbb.page.user.latestPostsAndThreads
 * @subpackage	page
 * @category 	Burning Board
 */
class LatestPostsAndThreadsPage extends MultipleLinkPage {
	// system
	public $templateName = 'latestPostsAndThreads';
	
	// list data
	public $listID = 0;
	public $list;
	
	// default values
	public $itemsPerPage = BOARD_THREADS_PER_PAGE;
	
	/**
	 * @see Page::readParameters()
	*/
	public function readParameters() {
		parent::readParameters();
		
		// get threads per page value
		if (WCF::getUser()->threadsPerPage) $this->itemsPerPage = WCF::getUser()->threadsPerPage;
		
		// get list id
		if (isset($_REQUEST['listID'])) $this->listID = intval($_REQUEST['listID']);
		// if no list id is set, display default list
		$this->list = ($this->listID ? new LatestPostsAndThreadsList($this->listID) : LatestPostsAndThreadsList::getDefaultList());
		// enter list
		$this->list->enter();
		$this->listID = ($this->listID ? $this->list->listID : 0);
	}
	
	/**
	 * @see Page::readData()
	 */
	public function readData() {
		parent::readData();
		
		// read threads
		$this->list->threadListLimit = $this->itemsPerPage;
		$this->list->threadListOffset = ($this->pageNo - 1) * $this->itemsPerPage;
		$this->list->readThreads();
	}
	
	/**
	 * @see Page::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			'standalone' => true,
			'threads' => ($this->list->threadList !== null ? $this->list->threadList->threads : null),
			'boards' => $this->list->boards,
			'listID' => $this->listID,
			'enableRating' => $this->list->getOption('showColumnRating'),
			'allowSpidersToIndexThisPage' => true
		));
		
		if (WCF::getSession()->spiderID) {
			if ($this->threadList != null && $this->threadList->maxLastPostTime) {
				@header('Last-Modified: '.gmdate('D, d M Y H:i:s', $this->threadList->maxLastPostTime).' GMT');
			}
		}
	}
	
	/**
	 * @see MultipleLinkPage::countItems()
	 */
	public function countItems() {
		parent::countItems();
		
		$this->list->initThreadList();
		return $this->list->threadList->countThreads();
	}
}
?>