<?php
// wcf imports
require_once(WCF_DIR.'lib/system/cache/CacheBuilder.class.php');

// wbb imports
require_once(WBB_DIR.'lib/data/thread/LatestPostsAndThreadsList.class.php');

/**
 * Caches all latest posts and threads list, the board ids connected to a latest posts and threads list, and the default list.
 * 
 * @author 	Nerd Almighty
 * @copyright	2009 Bergwerk <http://bergwerk.forenberg.de>
 * @license	Creative Commons - Attribution-Noncommercial-Share Alike 3.0 Unported <http://creativecommons.org/licenses/by-nc-sa/3.0/>
 * @package	com.bergwerk.wbb.page.user.latestPostsAndThreads
 * @subpackage	system.cache
 * @category 	Burning Board
 */
class CacheBuilderLatestPostsAndThreadsList implements CacheBuilder {
	/**
	 * @see CacheBuilder::getData()
	 */
	public function getData($cacheResource) {
		$data = array('lists' => array(), 'defaultList' => null, 'boardIDsToListID' => array());
		
		// get data from database
		$sql = "SELECT	*
			FROM	wbb".WBB_N."_latest_posts_and_threads_list";
		$result = WCF::getDB()->sendQuery($sql);
		while ($row = WCF::getDB()->fetchArray($result)) {
			// list
			$data['lists'][$row['listID']] = new LatestPostsAndThreadsList(null, $row);
			// default list
			if ($row['isDefault']) $data['defaultList'] = $data['lists'][$row['listID']];
			// board id to list id
			if ($row['isEnabled'] && strlen($row['parentBoards'])) {
				$boardIDs = explode(',', $row['parentBoards']);
				foreach ($boardIDs as $boardID) {
					$data['boardIDsToListID'][$boardID] = $row['listID'];
				}
			}
		}
		if ($data['defaultList'] === null) $data['defaultList'] = new LatestPostsAndThreadsList(null, null);
		
		return $data;
	}
}
?>