<?php
// wcf imports
require_once(WCF_DIR.'lib/system/event/EventListener.class.php');

/**
 * Adds the possibility to mark all boards included in a latest posts and threads list as read.
 * 
 * @author 	Nerd Almighty
 * @copyright	2009 Bergwerk <http://bergwerk.forenberg.de>
 * @license	Creative Commons - Attribution-Noncommercial-Share Alike 3.0 Unported <http://creativecommons.org/licenses/by-nc-sa/3.0/>
 * @package	com.bergwerk.wbb.page.user.latestPostsAndThreads
 * @subpackage	system.event.listener
 * @category 	Burning Board
 */
class BoardMarkAllAsReadActionLatestPostsAndThreadsListListener implements EventListener {
	/**
	 * @see EventListener::execute()
	 */
	public function execute($eventObj, $className, $eventName) {
		if (isset($_REQUEST['listID'])) {
			$listID = intval($_REQUEST['listID']);
			
			require_once(WBB_DIR.'lib/data/thread/LatestPostsAndThreadsList.class.php');
			$list = ($listID ? new LatestPostsAndThreadsList($listID) : LatestPostsAndThreadsList::getDefaultList());
			$list->enter();
			
			// get included boards
			$boardIDs = $list->getIncludedBoards();
			
			// mark all included boards as read
			if (WCF::getUser()->userID) {
				// in the database for users:
				$sqlValues = '';
				$userID = WCF::getUser()->userID;
				
				foreach ($boardIDs as $boardID) {
					$sqlValues .= (empty($sqlValues) ? '' : ',') . '('.$userID.','.$boardID.','.TIME_NOW.')';
				}
				
				if (!empty($sqlValues)) {
					$sql = "REPLACE INTO	wbb".WBB_N."_board_visit
								(userID, boardID, lastVisitTime)
						VALUES		".$sqlValues;
					WCF::getDB()->registerShutdownUpdate($sql);

					// update subscriptions
					require_once(WBB_DIR.'lib/data/thread/SubscribedThread.class.php');
					SubscribedThread::clearSubscriptions();
					
					$sql = "UPDATE	wbb".WBB_N."_board_subscription
						SET	emails = 0
						WHERE	userID = ".WCF::getUser()->userID."
							AND boardID IN (".implode(',', $boardIDs).")";
					WCF::getDB()->registerShutdownUpdate($sql);
					$sql = "UPDATE	wbb".WBB_N."_board_subscription
						SET	emails = 0
						WHERE	userID = ".WCF::getUser()->userID."
							AND threadID IN (
								SELECT threadID
								FROM	wbb".WBB_N."_thread
								WHERE	boardID IN (".implode(',', $boardIDs).")
							)";
					WCF::getDB()->registerShutdownUpdate($sql);
					
					// reset session
					WCF::getSession()->resetUserData();
					WCF::getSession()->unregister('lastSubscriptionsStatusUpdateTime');
				}
			}
			else {
				// as session var for guests:
				$boardVisits = WCF::getSession()->getVar('boardVisits');
				if ($boardVisits === false) $boardVisits = array();
				
				foreach ($boardIDs as $boardID) {
					$boardVisits[$boardID] = TIME_NOW;
				}
				
				WCF::getSession()->register('boardVisits', $boardVisits);
			}
			
			if (empty($_REQUEST['ajax'])) HeaderUtil::redirect('index.php?page=LatestPostsAndThreads'.($listID ? '&listID='.$listID : '').SID_ARG_2ND);
			exit;
		}
	}
}
?>