<?php
// wcf imports
require_once(WCF_DIR.'lib/system/event/EventListener.class.php');

/**
 * Adds the latest posts and threads list to the board page.
 * 
 * @author 	Nerd Almighty
 * @copyright	2009-2010 Bergwerk <http://bergwerk.forenberg.de>
 * @license	Creative Commons - Attribution-Noncommercial-Share Alike 3.0 Unported <http://creativecommons.org/licenses/by-nc-sa/3.0/>
 * @package	com.bergwerk.wbb.page.user.latestPostsAndThreads
 * @subpackage	system.event.listener
 * @category 	Burning Board
 */
class BoardPageLatestPostsAndThreadsListListener implements EventListener {
	/**
	 * @see EventListener::execute()
	 */
	public function execute($eventObj, $className, $eventName) {
		// check options and permissions
		if (!WCF::getUser()->userID || (WCF::getUser()->getUserOption('latestPostsAndThreadsListEnabled'))) {
			$boardID = $eventObj->boardID;
			// get list by board id
			require_once(WBB_DIR.'lib/data/thread/LatestPostsAndThreadsList.class.php');
			$list = LatestPostsAndThreadsList::getListByBoardID($boardID);
			if ($list !== false && $list->canBeAccessed()) {
				// get list status
				/* 
					UserSession->getStatus() is not implemented yet (WCF 1.1.0 Beta 2)
					$allClosedBoxes = (strlen(WCF::getUser()->getStatus('latestPostsAndThreadsBoxClosed')) ? explode(',', WCF::getUser()->getStatus('latestPostsAndThreadsBoxClosed')) : array());
				*/
				if (WCF::getUser()->userID) $allClosedBoxes = (strlen(WCF::getUser()->latestPostsAndThreadsBoxClosed) ? explode(',', WCF::getUser()->latestPostsAndThreadsBoxClosed) : array());
					else $allClosedBoxes = (strlen(WCF::getSession()->getVar('latestPostsAndThreadsBoxClosed')) ? explode(',', WCF::getSession()->getVar('latestPostsAndThreadsBoxClosed')) : array());
				$boxStatus = (!in_array($boardID, $allClosedBoxes));
				
				// open / close latest posts and threads list
				$latestPostsAndThreadsBoxClose = $latestPostsAndThreadsBoxOpen = 0;
				if (isset($_REQUEST['latestPostsAndThreadsBoxClose'])) $latestPostsAndThreadsBoxClose = intval($_REQUEST['latestPostsAndThreadsBoxClose']);
				if (isset($_REQUEST['latestPostsAndThreadsBoxOpen'])) $latestPostsAndThreadsBoxOpen = intval($_REQUEST['latestPostsAndThreadsBoxOpen']);
				
				if ($latestPostsAndThreadsBoxClose || $latestPostsAndThreadsBoxOpen) {
					$boxStatus = $latestPostsAndThreadsBoxOpen;
					$key = array_search($boardID, $allClosedBoxes);
					if (!$boxStatus && $key === false) $allClosedBoxes[] = $boardID;
					elseif ($boxStatus && $key !== false) unset($allClosedBoxes[$key]);
					// save status
					WCF::getUser()->saveStatus('latestPostsAndThreadsBoxClosed', implode(',', $allClosedBoxes));
				}
				
				// if list is initially closed, we do not have to read threads
				if ($boxStatus) {
					$list->threadListLimit = $list->getOption('length');
					$list->initThreadList($list->threadListLimit);
					$list->readThreads();
				}
				
				// get box template
				WCF::getTpl()->assign(array(
					'latestPostsAndThreadsList' => $list,
					'latestPostsAndThreadsListCount' => ($list->threadList !== null ? count($list->threadList->threads) : 0),
					'latestPostsAndThreadsBoxID' => $boardID,
					'latestPostsAndThreadsListStatus' => $boxStatus,
					'latestPostsAndThreadsListIsIndexList' => false
				));
				$template = WCF::getTpl()->fetch('latestPostsAndThreadsBox');
				
				// add template
				WCF::getTpl()->append('latestPostsAndThreadsBox', $template);
			}
		}
	}
}
?>